Debugging Interlude 1
:::::::::::::::::::::

.. toctree::
   :caption: Debugging Interlude 1
   :maxdepth: 2

   intro-HowtobeaSuccessfulProgrammer.rst
   HowtoAvoidDebugging.rst
   BeginningtipsforDebugging.rst
   KnowyourerrorMessages.rst
   Summary.rst
   Exercises.rst
